import type { PropType as __PropType } from 'vue';
import { BlurPass, KernelSize, BlendFunction } from 'postprocessing';
export type BloomProps = {
    blendFunction?: BlendFunction;
    /**
     * The intensity of the bloom effect.
     *
     * @default 1
     * @type {number}
     * @memberof BloomProps
     */
    intensity?: number;
    /**
     *  An efficient, incremental blur pass.
     *
     * @type {BlurPass}
     * @memberof BloomProps
     */
    blurPass?: BlurPass;
    /**
     * The width of the render
     *
     * @type {number}
     * @memberof BloomProps
     */
    width?: number;
    /**
     * The height of the render
     *
     * @type {number}
     * @memberof BloomProps
     */
    height?: number;
    /**
     * The kernel size.
     *
     * @default KernelSize.LARGE
     *
     * @type {KernelSize}
     * @memberof BloomProps
     */
    kernelSize?: KernelSize;
    /**
     * The luminance threshold. Raise this value to mask out darker elements in the scene. Range is [0, 1].
     *
     * @default 0.9
     *
     * @type {number}
     * @memberof BloomProps
     */
    luminanceThreshold?: number;
    /**
     * Controls the smoothness of the luminance threshold. Range is [0, 1].
     *
     * @default 0.025
     *
     * @type {number}
     * @memberof BloomProps
     */
    luminanceSmoothing?: number;
    /**
     * Enables mip map blur.
     *
     * @default false
     *
     * @type {boolean}
     * @memberof BloomProps
     */
    mipmapBlur?: boolean;
};
declare const _sfc_main: import("vue").DefineComponent<{
    blendFunction: {
        type: __PropType<BlendFunction | undefined>;
        required: false;
    };
    intensity: {
        type: __PropType<number | undefined>;
        required: false;
    };
    blurPass: {
        type: __PropType<import("postprocessing").KawaseBlurPass | undefined>;
        required: false;
    };
    width: {
        type: __PropType<number | undefined>;
        required: false;
    };
    height: {
        type: __PropType<number | undefined>;
        required: false;
    };
    kernelSize: {
        type: __PropType<KernelSize | undefined>;
        required: false;
    };
    luminanceThreshold: {
        type: __PropType<number | undefined>;
        required: false;
    };
    luminanceSmoothing: {
        type: __PropType<number | undefined>;
        required: false;
    };
    mipmapBlur: {
        type: __PropType<boolean | undefined>;
        required: false;
    };
}, {}, unknown, {}, {}, import("vue").ComponentOptionsMixin, import("vue").ComponentOptionsMixin, {}, string, import("vue").VNodeProps & import("vue").AllowedComponentProps & import("vue").ComponentCustomProps, Readonly<import("vue").ExtractPropTypes<{
    blendFunction: {
        type: __PropType<BlendFunction | undefined>;
        required: false;
    };
    intensity: {
        type: __PropType<number | undefined>;
        required: false;
    };
    blurPass: {
        type: __PropType<import("postprocessing").KawaseBlurPass | undefined>;
        required: false;
    };
    width: {
        type: __PropType<number | undefined>;
        required: false;
    };
    height: {
        type: __PropType<number | undefined>;
        required: false;
    };
    kernelSize: {
        type: __PropType<KernelSize | undefined>;
        required: false;
    };
    luminanceThreshold: {
        type: __PropType<number | undefined>;
        required: false;
    };
    luminanceSmoothing: {
        type: __PropType<number | undefined>;
        required: false;
    };
    mipmapBlur: {
        type: __PropType<boolean | undefined>;
        required: false;
    };
}>>, {}, {}>;
export default _sfc_main;
